summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/messagewidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/messagewidget.h')
-rw-r--r--umbrello/umbrello/messagewidget.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/umbrello/umbrello/messagewidget.h b/umbrello/umbrello/messagewidget.h
index 29383405..a0828da7 100644
--- a/umbrello/umbrello/messagewidget.h
+++ b/umbrello/umbrello/messagewidget.h
@@ -40,13 +40,14 @@ class MessageWidgetController;
*/
class MessageWidget : public UMLWidget, public LinkWidget {
Q_OBJECT
+ TQ_OBJECT
public:
friend class MessageWidgetController;
/**
* Constructs a MessageWidget.
*
- * @param view The parent to this class.
+ * @param view The tqparent to this class.
* @param a The role A widget for this message.
* @param b The role B widget for this message.
* @param y The vertical position to display this message.
@@ -61,7 +62,7 @@ public:
/**
* Constructs a MessageWidget.
*
- * @param view The parent to this class.
+ * @param view The tqparent to this class.
* @param sequenceMessageType The Uml::Sequence_Message_Type of this message widget
* @param id The ID to assign (-1 will prompt a new ID.)
*/
@@ -100,7 +101,7 @@ public:
* @param w The ObjectWidget to check for.
* @return true - if is contained, false - not contained.
*/
- bool contains(ObjectWidget * w);
+ bool tqcontains(ObjectWidget * w);
/**
* Returns the related widget on the given side.
@@ -208,7 +209,7 @@ public:
UMLClassifier * getSeqNumAndOp(TQString& seqNum, TQString& op);
/**
- * Calculate the geometry of the widget.
+ * Calculate the tqgeometry of the widget.
*/
void calculateWidget();
@@ -348,16 +349,16 @@ protected:
* Draw an arrow pointing in the given direction.
* The arrow head is not solid, i.e. it is made up of two lines
* like so: --->
* The direction can be either Qt::LeftArrow or Qt::RightArrow.
*/
static void drawArrow( TQPainter& p, int x, int y, int w,
- Qt::ArrowType direction, bool useDottedLine = false );
+ TQt::ArrowType direction, bool useDottedLine = false );
/**
* Draw a solid (triangular) arrowhead pointing in the given direction.
* The direction can be either Qt::LeftArrow or Qt::RightArrow.
*/
- static void drawSolidArrowhead(TQPainter& p, int x, int y, Qt::ArrowType direction);
+ static void drawSolidArrowhead(TQPainter& p, int x, int y, TQt::ArrowType direction);
/**
* Update the UMLWidget::m_bResizable flag according to the
@@ -348,16 +349,16 @@ protected:
* The arrow head is not solid, i.e. it is made up of two lines
* like so: --->
- * The direction can be either Qt::LeftArrow or Qt::RightArrow.
+ * The direction can be either TQt::LeftArrow or TQt::RightArrow.
*/
static void drawArrow( TQPainter& p, int x, int y, int w,
@@ -348,16 +349,16 @@ protected:
/**
* Draw a solid (triangular) arrowhead pointing in the given direction.
- * The direction can be either Qt::LeftArrow or Qt::RightArrow.
+ * The direction can be either TQt::LeftArrow or TQt::RightArrow.
*/